# API Reference

This page provides an auto-generated API reference for the key components of the `hydrodatasource` library.

## Reader

::: hydrodatasource.reader.data_source.SelfMadeHydroDataset
    handler: python
    options:
      show_root_heading: true
      show_source: false

## Processor

### Basin Mean Rainfall

::: hydrodatasource.processor.basin_mean_rainfall.basin_mean_func
    handler: python
    options:
      show_root_heading: true
      show_source: false

### Rainfall-Runoff Event Identification

::: hydrodatasource.processor.dmca_esr.get_rr_events
    handler: python
    options:
      show_root_heading: true
      show_source: false

## Cleaner

### RainfallCleaner

::: hydrodatasource.cleaner.rainfall_cleaner.RainfallCleaner
    handler: python
    options:
      show_root_heading: true
      show_source: false

### ReservoirInflowBacktrack

::: hydrodatasource.cleaner.rsvr_inflow_cleaner.ReservoirInflowBacktrack
    handler: python
    options:
      show_root_heading: true
      show_source: false

### StreamflowCleaner

::: hydrodatasource.cleaner.streamflow_cleaner.StreamflowCleaner
    handler: python
    options:
      show_root_heading: true
      show_source: false

### WaterlevelCleaner

::: hydrodatasource.cleaner.waterlevel_cleaner.WaterlevelCleaner
    handler: python
    options:
      show_root_heading: true
      show_source: false
